@@ -9,7 +9,7 @@
 #'
 #' @param model The output of a "preference space" model estimated
 #' using the `logitr()` function.
-#' @param priceName The name of the parameter that identifies price.
+#' @param price The name of the parameter that identifies price.
 #'
 #' @details
 #' Willingness to pay is computed by dividing the estimated parameters of a
@@ -19,51 +19,35 @@
 #' @return A data frame of the WTP estimates.
 #' @export
 #' @examples
-#' # Run a MNL model in the Preference Space:
 #' library(logitr)
 #'
+#' # Estimate a preference space model
 #' mnl_pref <- logitr(
-#'   data = yogurt,
-#'   choiceName = "choice",
-#'   obsIDName = "obsID",
-#'   parNames = c("price", "feat", "dannon", "hiland", "yoplait")
+#'   data   = yogurt,
+#'   choice = "choice",
+#'   obsID  = "obsID",
+#'   pars   = c("price", "feat", "brand")
 #' )
 #'
-#' # Get the WTP implied from the preference space model
-#' wtp(mnl_pref, priceName = "price")
-wtp <- function(model, priceName) {
-  if (is_logitr(model) == FALSE) {
-    stop('Model must be estimated using the"logitr" package')
-  }
-  if (is.null(priceName)) {
-    stop("Must provide priceName to compute WTP")
-  }
-  model <- allRunsCheck(model)
-  if (model$modelSpace == "pref") {
-    return(getPrefSpaceWtp(model, priceName))
-  } else if (model$modelSpace == "wtp") {
-    wtp_mean <- stats::coef(model)
-    wtp_se <- model$standErrs
-    return(getCoefSummaryTable(
-      wtp_mean, wtp_se, model$numObs, model$numParams))
-  }
-}
-
-getPrefSpaceWtp <- function(model, priceName) {
-  # Compute mean WTP
+#' # Compute the WTP implied from the preference space model
+#' wtp(mnl_pref, price = "price")
+wtp <- function(model, price) {
+  wtpInputsCheck(model, price)
   coefs <- stats::coef(model)
-  priceID <- which(names(coefs) == priceName)
+  priceID <- which(names(coefs) == price)
   pricePar <- -1 * coefs[priceID]
   wtp_mean <- coefs / pricePar
   wtp_mean[priceID] <- -1 * coefs[priceID]
   names(wtp_mean)[priceID] <- "lambda"
   # Compute standErrs using simulation (draws from the varcov matrix)
   draws <- getUncertaintyDraws(model, 10^5)
-  priceDraws <- repmatCol(-1 * draws[priceName], ncol(draws))
+  priceDraws <- repmatCol(-1 * draws[price], ncol(draws))
   wtpDraws <- draws / priceDraws
   wtpDraws[, priceID] <- draws[, priceID]
   wtp_se <- apply(wtpDraws, 2, stats::sd)
-  return(getCoefSummaryTable(wtp_mean, wtp_se, model$numObs, model$numParams))
+  result <- getCoefTable(wtp_mean, wtp_se)
+  class(result) <- c("logitr_wtp", "data.frame")
+  return(result)
 }
 
 #' Compare WTP from preference and WTP space models
@@ -76,7 +60,7 @@ getPrefSpaceWtp <- function(model, priceName) {
 #' the `logitr()` function.
 #' @param model_wtp The output of a "willingness to pay space" model estimated
 #' using the `logitr()` function.
-#' @param priceName The name of the parameter that identifies price.
+#' @param price The name of the parameter that identifies price.
 #'
 #' @details
 #' Willingness to pay (WTP) is first computed from the preference space model
@@ -88,42 +72,39 @@ getPrefSpaceWtp <- function(model, priceName) {
 #' WTP space models.
 #' @export
 #' @examples
-#' # Run a MNL model in the Preference Space:
 #' library(logitr)
 #'
+#' # Estimate a MNL model in the Preference space
 #' mnl_pref <- logitr(
-#'   data = yogurt,
-#'   choiceName = "choice",
-#'   obsIDName = "obsID",
-#'   parNames = c("price", "feat", "dannon", "hiland", "yoplait")
+#'   data   = yogurt,
+#'   choice = "choice",
+#'   obsID  = "obsID",
+#'   pars   = c("price", "feat", "brand")
 #' )
 #'
-#' # Get the WTP implied from the preference space model
-#' wtp_mnl_pref <- wtp(mnl_pref, priceName = "price")
+#' # Compute the WTP implied from the preference space model
+#' wtp_mnl_pref <- wtp(mnl_pref, price = "price")
 #'
-#' # Run a MNL model in the WTP Space:
+#' # Estimate a MNL model in the WTP Space, using the computed WTP values
+#' # from the preference space model as starting points
 #' mnl_wtp <- logitr(
-#'   data = yogurt,
-#'   choiceName = "choice",
-#'   obsIDName = "obsID",
-#'   parNames = c("feat", "dannon", "hiland", "yoplait"),
-#'   priceName = "price",
+#'   data       = yogurt,
+#'   choice     = "choice",
+#'   obsID      = "obsID",
+#'   pars       = c("feat", "brand"),
+#'   price      = "price",
 #'   modelSpace = "wtp",
-#'   options = list(startVals = wtp_mnl_pref$Estimate)
+#'   startVals  = wtp_mnl_pref$Estimate
 #' )
 #'
-#' # Compare the WTP between the two spaces:
-#' wtpCompare(mnl_pref, mnl_wtp, priceName = "price")
-wtpCompare <- function(model_pref, model_wtp, priceName) {
-  if (is_logitr(model_pref) == FALSE | is_logitr(model_wtp) == FALSE) {
-    stop('Models must be estimated using the "logitr" package')
-  }
-  model_pref <- allRunsCheck(model_pref)
-  model_wtp <- allRunsCheck(model_wtp)
-  pref <- wtp(model_pref, priceName)$Estimate
+#' # Compare the WTP between the two spaces
+#' wtpCompare(mnl_pref, mnl_wtp, price = "price")
+wtpCompare <- function(model_pref, model_wtp, price) {
+  wtpCompareInputsCheck(model_pref, model_wtp, price)
+  pref <- wtp(model_pref, price)$Estimate
   pref <- c(pref, model_pref$logLik)
   wtp <- stats::coef(model_wtp)
-  wtp <- c(wtp, model_wtp$logLik)
+  wtp <- c(wtp, stats::logLik(model_wtp))
   names(pref)[length(pref)] <- "logLik"
   names(wtp)[length(wtp)] <- "logLik"
   compare <- data.frame(pref = pref, wtp = wtp)
